# GDI_effects
GDI_effects is a Python library that allows you to create GDI screen effects on Windows.

## Installation
You can install this library via pip:
```bash
pip install GDI_effects
```

## Usage
Below is an example of how to use the library to create various screen effects:
```py
from GDI_effects import *
```

## Available Functions
`BWscreen()`: Creates a black and white effect on the screen.

`errorscreen()`: Displays error icons at various positions on the screen.

`invertscreen()`: Inverts the colors on the screen.

`panscreen()`: Pans the screen in random directions.

`Rainbowhell()`: Creates random rainbow effects on the screen.

`screenwavy()`: Creates a wavy effect on the screen.

`voidscreen()`: Creates a void effect on the screen.

`glitchscreen()`: Creates a glitch effect on the screen.

## Contributing
If you would like to contribute to this project, please fork the repository, create a new branch for your changes, and submit a pull request.